==> vaycore-0.7.0.tar.gz: lib/src/http/dio/default_adapter.dart <==
import 'dart:io';

import 'package:dio/dio.dart';
import 'package:vaycore/http.dart';
import 'package:vaycore/vaycore.dart';

//
// @author vay
// @email hxhvay@126.com
// @date 2020-05-09
//

class DefaultAdapter extends BaseNetAdapter {
  Dio _dio;
  Map<String, dynamic> _defaultHeaders;

  DefaultAdapter({
    String baseApiUrl,
    int connectTimeout = 15000,
  }) {
    this._defaultHeaders = {HttpHeaders.userAgentHeader: "dio-3.0.9"};
    this._dio = Dio(BaseOptions(
        baseUrl: baseApiUrl ?? "",
        connectTimeout: connectTimeout,
        validateStatus: (status) {
          return status >= 200 && status < 300 || status == 304;
        }));
  }

  void _initInterceptors() {
    if (_dio.interceptors == null) {
      return;
    }
    _dio.interceptors.clear();
    if (core.options.isDebug) {
      _dio.interceptors.add(LogInterceptor(
          request: core.options.httpLog.request,
          requestHeader: core.options.httpLog.requestHeader,
          requestBody: core.options.httpLog.requestBody,
          responseHeader: core.options.httpLog.responseHeader,
          responseBody: core.options.httpLog.responseBody,
          error: core.options.httpLog.error,
          logPrint: core.options.httpLog.logPrint));
    }
  }

  @override
  Future<HttpResult<T>> request<T>(RequestParams params) async {
    assert(params != null);
    if (params.transformer != null) {
      _dio.transformer = params.transformer;
    }

    // 防止重复添加
    _initInterceptors();
    if (params.interceptors != null && params.interceptors.isNotEmpty) {
      params.interceptors.forEach((element) {
        _dio.interceptors.add(element);
      });
    }

    String url = wrapUrlByParams(params.method, params.url, params.data);
    Response response;
    T data;
    try {
      response = await _doRequest(url, params);
      if (params.parser != null) {
        data = params.parser<T>(response.data);
      } else {
        data = response.data;
      }
      return HttpResult<T>(
        ResultStatus.success,
        data: data,
        httpStatus: response.statusCode,
      );
    } catch (e) {
      return HttpResult<T>(
        ResultStatus.failed,
        error: e,
        httpStatus: response?.statusCode ?? HttpStatus.internalServerError,
      );
    }
  }

  Future<Response> _doRequest(String url, RequestParams params) async {
    Options options = _buildOptions(params);
    Future<Response> response;
    switch (params.method) {
      case HttpMethod.POST:
        response = _dio.post(url, data: params.data, options: options);
        break;
      case HttpMethod.PUT:
        response = _dio.put(url, data: params.data, options: options);
        break;
      case HttpMethod.DELETE:
        response = _dio.delete(url, data: params.data, options: options);
        break;
      case HttpMethod.HEAD:
        response = _dio.head(url, options: options);
        break;
      case HttpMethod.PATCH:
        response = _dio.patch(url, options: options);
        break;
      case HttpMethod.GET:
      default:
        response = _dio.get(url, options: options);
        break;
    }
    return response;
  }

  /// 使用RequestParams构建options对象
  Options _buildOptions(RequestParams params) {
    return Options(
      sendTimeout: params.timeout,
      receiveTimeout: params.timeout,
      headers: params.header ?? _defaultHeaders,
      contentType: params.contentType ?? Headers.jsonContentType,
      responseType: params.responseType ?? ResponseType.json,
    );
  }
}

==> vaycore-1.0.1.tar.gz: lib/src/http/dio/default_adapter.dart <==
//
// @author vay
// @email hxhvay@126.com
// @date 2020-05-09
//

import 'package:vaycore/http.dart';

import 'dart:io';
import 'package:dio/dio.dart';

import 'package:vaycore/vaycore.dart';

class DefaultAdapter extends BaseNetAdapter {
  Dio _dio;
  Map<String, dynamic> _defaultHeaders;
  HttpLogOptions _options;

  DefaultAdapter({
    String baseApiUrl,
    int connectTimeout = 15000,
  }) {
    this._defaultHeaders = {HttpHeaders.userAgentHeader: "dio-3.0.9"};
    this._options = core.engine.buildHttpLogOptions();
    this._dio = Dio(BaseOptions(
        baseUrl: baseApiUrl ?? "",
        connectTimeout: connectTimeout,
        validateStatus: (status) {
          return status >= 200 && status < 300 || status == 304;
        }));
  }

  void _initInterceptors() {
    if (_dio.interceptors == null) {
      return;
    }
    _dio.interceptors.clear();
    if (core.isDebug) {
      _dio.interceptors.add(LogInterceptor(
          request: this._options.request,
          requestHeader: this._options.requestHeader,
          requestBody: this._options.requestBody,
          responseHeader: this._options.responseHeader,
          responseBody: this._options.responseBody,
          error: this._options.error,
          logPrint: this._options.logPrint));
    }
  }

  @override
  Future<HttpResult<T>> request<T>(RequestParams params) async {
    assert(params != null);
    if (params.transformer != null) {
      _dio.transformer = params.transformer;
    }

    // 防止重复添加
    _initInterceptors();
    if (params.interceptors != null && params.interceptors.isNotEmpty) {
      params.interceptors.forEach((element) {
        _dio.interceptors.add(element);
      });
    }

    String url = wrapUrlByParams(params.method, params.url, params.data);
    Response response;
    T data;
    try {
      response = await _doRequest(url, params);
      if (params.parser != null) {
        data = params.parser<T>(response.data);
      } else {
        data = response.data;
      }
      return HttpResult<T>(
        ResultStatus.success,
        data: data,
        httpStatus: response.statusCode,
      );
    } catch (e) {
      return HttpResult<T>(
        ResultStatus.failed,
        error: e,
        httpStatus: response?.statusCode ?? HttpStatus.internalServerError,
      );
    }
  }

  Future<Response> _doRequest(String url, RequestParams params) async {
    Options options = _buildOptions(params);
    Future<Response> response;
    switch (params.method) {
      case HttpMethod.POST:
        response = _dio.post(url, data: params.data, options: options);
        break;
      case HttpMethod.PUT:
        response = _dio.put(url, data: params.data, options: options);
        break;
      case HttpMethod.DELETE:
        response = _dio.delete(url, data: params.data, options: options);
        break;
      case HttpMethod.HEAD:
        response = _dio.head(url, options: options);
        break;
      case HttpMethod.PATCH:
        response = _dio.patch(url, options: options);
        break;
      case HttpMethod.GET:
      default:
        response = _dio.get(url, options: options);
        break;
    }
    return response;
  }

  /// 使用RequestParams构建options对象
  Options _buildOptions(RequestParams params) {
    return Options(
      sendTimeout: params.timeout,
      receiveTimeout: params.timeout,
      headers: params.header ?? _defaultHeaders,
      contentType: params.contentType ?? Headers.jsonContentType,
      responseType: params.responseType ?? ResponseType.json,
    );
  }
}
